#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Oct 15 11:15:45 2019

@author: quentinpeter
"""

import os
from CoreServices.LaunchServices import (LSCopyDefaultRoleHandlerForContentType,
                            LSSetDefaultRoleHandlerForContentType,
                            LSCopyDefaultHandlerForURLScheme,
                            LSSetDefaultHandlerForURLScheme,
                            LSOpenCFURLRef,
                            kLSRolesNone,
                            kLSRolesViewer,
                            kLSRolesEditor,
                            kLSRolesShell,
                            kLSRolesAll)

from AppKit import NSRunningApplication, NSBundle, NSURL


name = "applaunchservices"

kLSRoles = {
    'none': kLSRolesNone,
    'viewer': kLSRolesViewer,
    'editor': kLSRolesEditor,
    'shell': kLSRolesShell,
    'all': kLSRolesAll
    }


def get_bundle_identifier(pid=None):
    """
    Get bundle identifier for the given process identifier.

    if pid is None, the current process pid is used.
    """
    if pid is None:
        pid = os.getpid()
    app = NSRunningApplication.runningApplicationWithProcessIdentifier_(pid)
    if app is None:
        return
    return app.bundleIdentifier()


def get_bundle_identifier_for_path(path):
    """
    Get bundle identifier for the given path.
    """
    bundle_url = 'file://' + os.path.abspath(path)
    return NSBundle.bundleWithURL_(
        NSURL.URLWithString_(bundle_url)).bundleIdentifier()


def set_UTI_handler(uniform_type_identifier, role, bundle_identifier):
    """Set handler for given uniform type identifier and role."""
    LSSetDefaultRoleHandlerForContentType(
        uniform_type_identifier, kLSRoles[role], bundle_identifier)


def get_UTI_handler(uniform_type_identifier, role):
    """Get handler for given uniform type identifier and role."""
    return LSCopyDefaultRoleHandlerForContentType(
        uniform_type_identifier, kLSRoles[role])


def set_URL_scheme_handler(url_scheme, bundle_identifier):
    """Set handler for given URL scheme."""
    LSSetDefaultHandlerForURLScheme(url_scheme, bundle_identifier)


def get_URL_scheme_handler(url_scheme):
    """Get handler for given URL scheme."""
    return LSCopyDefaultHandlerForURLScheme(url_scheme)


def open_URL(url):
    """Open the url with launchservices."""
    URL = NSURL.URLWithString_(url)
    LSOpenCFURLRef(URL, None)


def open_path(path):
    """Open the path with launchservices."""
    open_URL('file://' + os.path.abspath(path))



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
This file is distributed under the following licence:

this project is licensed under 2-clause BSD

Copyright (c) 2013, Min Ragan-Kelley

All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this
list of conditions and the following disclaimer.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""
__version__ = '0.3.0'

import sys
import platform
from distutils.version import LooseVersion as V

try:
    import CoreServices.LaunchServices
    import AppKit
    HAS_LS = True
except ImportError:
    HAS_LS = False


if (not HAS_LS
      or sys.platform != "darwin"
      or V(platform.mac_ver()[0]) < V("10.4")):
    from ._dummy import *
else:
    from ._ls import *

if HAS_LS:
    del CoreServices.LaunchServices, AppKit
del sys, platform, V